# Changelog

## [0.1.3](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.3) (2022-05-03)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.2...0.1.3)

**Merged pull requests:**

- GUI enhancements [\#10](https://github.com/firefly-cpp/AST-Monitor/pull/10) ([luckyLukac](https://github.com/luckyLukac))
- Redesigned GUI [\#9](https://github.com/firefly-cpp/AST-Monitor/pull/9) ([luckyLukac](https://github.com/luckyLukac))
- Update README.md [\#6](https://github.com/firefly-cpp/AST-Monitor/pull/6) ([alenrajsp](https://github.com/alenrajsp))

## [0.1.2](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.2) (2022-03-10)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.1...0.1.2)

**Closed issues:**

- 'ant' module cannot be installed using PIP [\#1](https://github.com/firefly-cpp/AST-Monitor/issues/1)

**Merged pull requests:**

- Small changes in GUI [\#4](https://github.com/firefly-cpp/AST-Monitor/pull/4) ([luckyLukac](https://github.com/luckyLukac))
- Code refactored to comply with Flake standards [\#3](https://github.com/firefly-cpp/AST-Monitor/pull/3) ([luckyLukac](https://github.com/luckyLukac))
- Small bugfix at pyqt-feedback-flow usage [\#2](https://github.com/firefly-cpp/AST-Monitor/pull/2) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.1) (2022-01-25)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/c3527a1296385a84a0b0be4df0e1609527cbac67...0.1.1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
